@@ -4,7 +4,7 @@ from typing import Any, Callable, Dict, List, Optional, Tuple
 from dataclasses import dataclass, field
 
 from .. import processors, validators
-from .schemas import ValidationStepSchema
+from .schemas import ValidationResultSchema, ValidationStepSchema
 from .utils import list_functions, resolve_function
 
 
@@ -141,3 +141,10 @@ def load_ValidationStep(data: dict) -> ValidationStep:  # type: ignore
         processor=loaded_processor,
         validators=loaded_validators,
     )
+
+
+validation_result_schema = ValidationResultSchema()
+
+
+def dump_ValidationResult(result: ValidationResult) -> dict:
+    return validation_result_schema.dump(result)
